﻿using Infragistics.Windows.DockManager;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace XamDockManager_Test
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            DataContext = this;
            Dock_Manager.AllowMinimizeFloatingWindows = true;
            Dock_Manager.ShowFloatingWindowsInTaskbar = true;
        }



        public bool RestoreWindows
        {
            get { return (bool)GetValue(RestoreWindowsProperty); }
            set { SetValue(RestoreWindowsProperty, value); }
        }

        // Using a DependencyProperty as the backing store for RestoreWindows.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty RestoreWindowsProperty =
            DependencyProperty.Register("RestoreWindows", typeof(bool), typeof(MainWindow), new PropertyMetadata(false));

        

        private void Add_Content_Click(object sender, RoutedEventArgs e)
        {
            //We want to recycle existing panes, so we will search for the existing pane first
            foreach (ContentPane cp in Dock_Manager.GetPanes(PaneNavigationOrder.ActivationOrder))
            {
                if (cp.Name == "test")
                {

                    if (cp.Visibility == System.Windows.Visibility.Visible)
                    {
                        if (RestoreWindows)
                        {
                            var window = Window.GetWindow(cp);
                            if (window != null && window.WindowState == System.Windows.WindowState.Minimized)
                            {
                                window.WindowState = WindowState.Normal;
                            }
                        }
                    }
                    else
                    {
                        //Assign screen content
                        cp.Content = new ScreenContent();

                        //Activate pane and make visible
                        cp.ExecuteCommand(ContentPaneCommands.ActivatePane);
                        cp.Visibility = System.Windows.Visibility.Visible;

                        // When the user wants to show this screen again, it's possible that the pane already exists and is minimized.
                        // In this case we restore the existing window, this works fine

                        //The problem is if the user has closed the pane while it is minimized, 
                        // this can be done by first minimizing the window and then hover over the item in the task bar and click the x button to close.
                        // Then when we show the screen again we restore the window, except this time the screen content has not loaded yet and when it does the pane does not maintain original size
                        if (RestoreWindows)
                        {                            
                            var window = Window.GetWindow(cp);
                            if (window != null && window.WindowState == System.Windows.WindowState.Minimized)
                            {
                                window.WindowState = WindowState.Normal;
                            }
                        }
                    }

                    return;
                }
            }

            var pane = new SplitPane();
            XamDockManager.SetInitialLocation(pane, InitialPaneLocation.FloatingOnly);
            var contentPane = new ContentPane();

            //When the content pane is closed, clear out content
            contentPane.Closing += (a1, a2) =>
            {
                contentPane.Content = null;
            };

            //Assign screen content (for this example just a grid wrapped in a scrollviewer)
            contentPane.Content = new ScreenContent();

            //Set close action to hide pane
            contentPane.CloseAction = PaneCloseAction.HidePane;

            //Add pane name so we can find it again later and recycle the pane
            contentPane.Name = "test";

            //Add to splitpane and dockmanager
            pane.Panes.Add(contentPane);
            Dock_Manager.Panes.Add(pane);
        }
    }
}
